@@ -9,7 +9,9 @@ no warnings qw(experimental::lexical_subs);
 
 package Spreadsheet::Edit::Log;
 
-our $VERSION = '3.024'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+# Allow "use <thismodule. VERSION ..." in development sandbox to not bomb
+{ no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 998.999; }
+our $VERSION = '3.025'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
 our $DATE = '2023-06-09'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Exporter 'import';
