@@ -8,7 +8,10 @@ use strict; use warnings FATAL => 'all'; use feature qw/say state/;
 use utf8;
 
 package Spreadsheet::Edit::Preload;
-our $VERSION = '3.024'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+
+# Allow "use <thismodule. VERSION ..." in development sandbox to not bomb
+{ no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 998.999; }
+our $VERSION = '3.025'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
 our $DATE = '2023-06-09'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Carp;
